#!/bin/csh
# Copyright (C) 2019-2021:
#   Max Planck Institut fuer extraterrestrische Physik
#
# This file is part of eRosita's ESASS (https://erosita.mpe.mpg.de/). It is free software; you can
# redistribute it and/or modify it under the terms of the GNU General
# Public License as published by the Free Software Foundation; either
# version 2 of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
# USA, or see https://www.gnu.org/licenses/.
#

# HBrunner 2006-09-01 last update: 2019-02-20
# tcsh version adapted from bash version by: 
# TDwelly  2013-02-13

echo "package SASS"

# define directory paths
setenv SASS_SETUP "$SASS_ROOT/sass/setup"
setenv SASS_TESTDATA "$SASS_ROOT/sass/testdata"
setenv SASS_PAR "$SASS_ROOT/par"
setenv E_ROOT "$SASS_ROOT/erosita"

alias unpack_package "$SASS_SETUP/unpack_package.csh"
alias build_package "$SASS_SETUP/build_package.csh"
alias make_dist "$SASS_SETUP/make_dist.csh"
alias touch_lib "$SASS_SETUP/touch_lib.csh"
alias depend "$SASS_SETUP/depend.csh"
alias make_pkgdist "$SASS_SETUP/make_pkg.csh"
alias make_release "$SASS_SETUP/make_release.csh"
alias unpack_release "$SASS_SETUP/unpack_release.csh"

alias build_all "$SASS_SETUP/devel/build_all.csh"
alias update_all "$SASS_SETUP/devel/update_all.csh"
alias make_pkgdist "$SASS_SETUP/devel/make_pkgdist.csh"
alias changelog "$SASS_SETUP/devel/changelog.csh"
alias mkdoc "$SASS_SETUP/devel/mkdoc.csh"
alias patch_release "$SASS_SETUP/devel/patch_release.csh"

# set PFILES (PIL parameter file directory) 
# if ( ! ${?PFILES} ) setenv PFILES $HOME/pfiles\;
# setenv PFILES ${PFILES}:$SASS_ROOT/par

# set PFILES (improved version by Philipp Weber)
# 3 cases:
# 1.: set with ; as a delimiter
#	Usual splitting and setting
# 2.: set with no ;
#	Apparently then only the user specific path is set
#	So: Just set the ; and append $SASS_PAR
# 3.: not set at all

# if pfiles not set then set it to empty
if ( ! $?PFILES ) then
  setenv PFILES ""
endif

set split = ( $PFILES:as/;/ / )

if ( $#split == 2 ) then 			# case 1
  set userpfiles = $split[1]
  set syspfiles = ${SASS_PAR}:$split[2]
else if ( $#split == 1) then			# case 2
  set userpfiles = $split[1]
  set syspfiles = ${SASS_PAR}
else						# case 3
  set userpfiles = ${HOME}/pfiles
  set syspfiles = ${SASS_PAR}
endif

# Make sure the users pfiles directory is present and writeable
if ( ! -w $userpfiles ) then
  mkdir -p $userpfiles
  if ( $? != 0 ) then
    echo "eSASS setup error: Could not create local pfiles directory at \"$userpfiles\""
    exit 1
  endif
endif

# remove redundant entries from syspfiles
set syspfiles=`printf "%s" "$syspfiles" | awk -v RS=':' '\\!a[$1]++ { if (NR > 1) printf RS; printf $1 }'`
set userpfiles=`printf "%s" "$userpfiles" | awk -v RS=':' '\\!a[$1]++ { if (NR > 1) printf RS; printf $1 }'`
# Just in case, remove duplicated ":"
set syspfiles=`echo $syspfiles | tr -s ':'`
set userpfiles=`echo $userpfiles | tr -s ':'`
# And also just in case remove any : at the start of each part of the variable
set syspfiles=`echo $syspfiles | sed 's/^:\+//g'`
set userpfiles=`echo $userpfiles | sed 's/^:\+//g'`
# And the same with trailing semicolons
set syspfiles=`echo $syspfiles | sed 's/:\+$//g'`
set userpfiles=`echo $userpfiles | sed 's/:\+$//g'`

setenv PFILES "$userpfiles;$syspfiles"




