#!/bin/bash
# Copyright (C) 2019-2021:
#   Max Planck Institut fuer extraterrestrische Physik
#
# This file is part of eRosita's ESASS (https://erosita.mpe.mpg.de/). It is free software; you can
# redistribute it and/or modify it under the terms of the GNU General
# Public License as published by the Free Software Foundation; either
# version 2 of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
# USA, or see https://www.gnu.org/licenses/.
#

# HBrunner 2006-09-01 last update: 2019-02-20

echo "package SASS"

# define directory paths
export SASS_SETUP="$SASS_ROOT/sass/setup"
export SASS_TESTDATA="$SASS_ROOT/sass/testdata"
export SASS_PAR="$SASS_ROOT/par"
export E_ROOT="$SASS_ROOT/erosita"

alias unpack_package="$SASS_SETUP/unpack_package.csh"
alias build_package="$SASS_SETUP/build_package.csh"
alias make_dist="$SASS_SETUP/make_dist.csh"
alias touch_lib="$SASS_SETUP/touch_lib.csh"
alias depend="$SASS_SETUP/depend.csh"
alias make_release="$SASS_SETUP/make_release.csh"
alias make_release="$SASS_SETUP/make_pkg.csh"
alias unpack_release="$SASS_SETUP/unpack_release.csh"

alias build_all="$SASS_SETUP/devel/build_all.csh"
alias update_all="$SASS_SETUP/devel/update_all.csh"
alias make_pkgdist="$SASS_SETUP/devel/make_pkgdist.csh"
alias changelog="$SASS_SETUP/devel/changelog.csh"
alias mkdoc="$SASS_SETUP/devel/mkdoc.csh"
alias patch_release="$SASS_SETUP/devel/patch_release.csh"

# set PFILES (PIL parameter file directory) 
# if test -z $PFILES ; then export PFILES=$HOME/pfiles\;$SASS_ROOT/par ; else PFILES=$PFILES:$SASS_ROOT/par ; fi

# set PFILES (improved version by Philipp Weber)
# 3 cases:
# 1.: set with ; as a delimiter
#       Usual splitting and setting
# 2.: set with no ;
#       Apparently then only the user specific path is set
#       So: Just set the ; and append $SASS_PAR
# 3.: not set at all

if [[ $PFILES == *";"* ]]               # case 1
then
  userpfiles=${PFILES%%;*}
  syspfiles=${SASS_PAR}:${PFILES##*;}
elif [[ ! -z ${PFILES} ]]               # case 2
then
  # here we assume that if there is not ; in the variable,
  # the part which is present is the users personal pfiles directory
  # everything else wouldn't work at all with the PIL
  userpfiles=${PFILES}
  syspfiles=${SASS_PAR}
else                                    # case3
  userpfiles=${HOME}/pfiles
  syspfiles=${SASS_PAR}
fi

# Make sure the users pfiles directory is present and writeable
if [[ ! -w $userpfiles ]]
then
  # if not try to create it
  mkdir -p $userpfiles
  if [ $? -ne 0 ]
  then
    # in case of an error bail out with message
    echo "eSASS setup error: Could not create local pfiles directory at \"$userpfiles\""
    exit 1
  fi
fi

# remove redundant entries from syspfiles
syspfiles=$(printf "%s" "$syspfiles" | awk -v RS=':' '!a[$1]++ { if (NR > 1) printf RS; printf $1 }')
userpfiles=$(printf "%s" "$userpfiles" | awk -v RS=':' '!a[$1]++ { if (NR > 1) printf RS; printf $1 }')
# Just in case, remove duplicated ":"
syspfiles=$(echo $syspfiles | tr -s ':')
userpfiles=$(echo $userpfiles | tr -s ':')
# And also just in case remove any : at the start of each part of the variable
syspfiles=$(echo $syspfiles | sed 's/^:\+//g')
userpfiles=$(echo $userpfiles | sed 's/^:\+//g')
# And the same with trailing semicolons
syspfiles=$(echo $syspfiles | sed 's/:\+$//g')
userpfiles=$(echo $userpfiles | sed 's/:\+$//g')

export PFILES="$userpfiles;$syspfiles"
