# Copyright (C) 2019-2021:
#   Max Planck Institut fuer extraterrestrische Physik
#
# This file is part of eRosita's ESASS (https://erosita.mpe.mpg.de/). It is free software; you can
# redistribute it and/or modify it under the terms of the GNU General
# Public License as published by the Free Software Foundation; either
# version 2 of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
# USA, or see https://www.gnu.org/licenses/.
#

#! /bin/tcsh
# call enable scripts
# HBrunner 2006-06-21 last update: 2016-12-02
# tcsh version adapted from bash version by:
# TDwelly  2013-02-13 last update: 2016-11-08 - fixed typo in setenv LIBRARY_PATH

#======================== site specific ==========================
# CG proposed change
if (! $?FC) then
    echo "FC is undefined - set to gfortran"
    setenv FC gfortran
  else
    echo "FC defined as $FC"
endif

if (! $?CC) then
    echo "CC is undefined - set to gcc"
    setenv CC gcc
  else
    echo "CC defined as $CC"
endif

if (! $?CXX) then
    echo "CXX is undefined - set to g++"
    setenv CXX g++
  else
    echo "CXX defined as $CXX"
endif

# Adjust SASS_HOME to your local setup:
setenv SASS_HOME /home/erosita
setenv SASS_DIR $SASS_HOME/sw
#-----------------------------------------------------------------
# Comment out this section to use the system compiler instead of 
# the one supplied in the external directory. You will need to 
# rebuild the pil package (also in the external directory) and 
# edit the default.libs file (directory sass/setup) in this case:

if ( ! ${?LIBRARY_PATH} ) setenv LIBRARY_PATH
setenv LIBRARY_PATH "/lib/x86_64-linux-gnu:/lib64:/lib:/usr/lib/x86_64-linux-gnu:/usr/lib64:/usr/lib:$LIBRARY_PATH"
if ( ! ${?LD_LIBRARY_PATH} ) setenv LD_LIBRARY_PATH
setenv LD_LIBRARY_PATH "/lib/x86_64-linux-gnu:/lib64:/lib:/usr/lib/x86_64-linux-gnu:/usr/lib64:/usr/lib:$LD_LIBRARY_PATH"

#setenv PATH "$SASS_DIR/external/gfortran/gcc-4.9/bin:$PATH"
#setenv LD_LIBRARY_PATH "$SASS_DIR/external/gfortran/gcc-4.9/lib64:$LD_LIBRARY_PATH"
#-------------------HEADAS     ----------------------------------------------
# To use a specific headas version
# comment the test no HEADAS Variable and 
#uncomment the export HEADAS line and complete it with the headas distribution path 

# Comment out this section to use your system HEASOFT package
# (you will also need to edit the default.libs file in directory 
# sass/setup in this case): 
#setenv HEADAS "$SASS_DIR/external/heasoft-6.19/x86_64-unknown-linux-gnu-libc2.19-0"
# setenv PATH "$HEADAS/bin:$PATH"
if ( ! ${?LD_LIBRARY_PATH} ) setenv LD_LIBRARY_PATH
setenv LD_LIBRARY_PATH "$HEADAS/lib:${LD_LIBRARY_PATH}"
#-----------------------------------------------------------------
# Other packages: edit file default.libs (directory sass/setup) to 
# use your local versions instead of the ones supplied in the
# external directory.

# Comment out if you are not using the fft package in the external
# directory:
setenv LD_LIBRARY_PATH "$SASS_DIR/external/fftw33:$LD_LIBRARY_PATH"
#=================================================================

if ( $#argv != 1 ) then
  echo "Error: You must supply the release code, options are:"
  /bin/ls $SASS_HOME/sw/*/RELEASE | awk '//{n=split($1,a,"/");print a[n-1]}'
  exit 1
endif

source $SASS_HOME/caldb/software/tools/caldbinit.csh
setenv SASS_CALVERS  $SASS_HOME/caldb/data/erosita/calvers.indx
echo "SASS_ROOT: SASS_CALVERS ", ${argv[1]}

setenv SASS_ROOT $SASS_DIR/${argv[1]}
echo "SASS_ROOT: $SASS_ROOT"

setenv SASS_BIN_ROOT $SASS_ROOT/bin
setenv PATH "${SASS_BIN_ROOT}:${PATH}"
setenv SASS_SETUP $SASS_ROOT/sass/setup
setenv SW_ARCHIVE $SASS_DIR/sw_archive
setenv SW_EXPARCH $SASS_DIR/sw_exparch

source $SASS_SETUP/enable_sass.csh
source $SASS_SETUP/enable_erosita.csh

# Increase stack size:
limit stacksize 32768k

echo "setup complete"
