#! /bin/bash
# Copyright (C) 2019-2021:
#   Max Planck Institut fuer extraterrestrische Physik
#
# This file is part of eRosita's ESASS (https://erosita.mpe.mpg.de/). It is free software; you can
# redistribute it and/or modify it under the terms of the GNU General
# Public License as published by the Free Software Foundation; either
# version 2 of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
# USA, or see https://www.gnu.org/licenses/.
#

# call enable scipts
# HBrunner 2006-06-21 last update: 2016-12-02

#======================== site specific ==========================

# CG - check if FC env for gfortran is set
if [ -z "$FC" ]
then
	echo "set default FC to gfortran"
    export FC=gfortran
else 
    echo "FC defined as ${FC}"
fi

if [ -z "$CC" ]
then
        echo "set default CC to gcc"
    export CC=gcc
else
    echo "CC defined as ${CC}"
fi

if [ -z "$CXX" ]
then
        echo "set default CXX to g++"
    export CXX=g++
else
    echo "CXX defined as ${CXX}"
fi


# Adjust SASS_HOME to your local setup:
export SASS_HOME=/home/erosita
export SASS_DIR=$SASS_HOME/sw
#-----------------------------------------------------------------
# Comment out this section to use the system compiler instead of 
# the one supplied in the external directory. You will need to 
# rebuild the pil package (also in the external directory) and 
# edit the default.libs file (directory sass/setup) in this case:

if test -z $LIBRARY_PATH ; then export LIBRARY_PATH=/lib/x86_64-linux-gnu:/lib64:/lib:/usr/lib/x86_64-linux-gnu:/usr/lib64:/usr/lib ; else export LIBRARY_PATH=/lib/x86_64-linux-gnu:/lib64:/lib:/usr/lib/x86_64-linux-gnu:/usr/lib64:/usr/lib:$LIBRARY_PATH ; fi
if test -z $LD_LIBRARY_PATH ; then export LD_LIBRARY_PATH=/lib/x86_64-linux-gnu:/lib64:/lib:/usr/lib/x86_64-linux-gnu:/usr/lib64:/usr/lib ; else export LD_LIBRARY_PATH=/lib/x86_64-linux-gnu:/lib64:/lib:/usr/lib/x86_64-linux-gnu:/usr/lib64:/usr/lib:$LD_LIBRARY_PATH ; fi

PATH=$SASS_DIR/external/gfortran/gcc-4.9/bin:$PATH
if test -z $LD_LIBRARY_PATH ; then export LD_LIBRARY_PATH=$SASS_DIR/external/gfortran/gcc-4.9/lib64 ; else export LD_LIBRARY_PATH=$SASS_DIR/external/gfortran/gcc-4.9/lib64:$LD_LIBRARY_PATH ; fi
#-----------------------------------------------------------------
# To use a specific headas version
# comment the test no HEADAS Variable ans 
#uncomment the export HEADAS line and complete it with the headas distribution path 
if  test -z $HEADAS ; then echo "WARNING HEADAS veriable not defined you won't be able to use eSASS"; return; fi 
#export HEADAS="$SASS_DIR/external/heasoft-6.19/x86_64-unknown-linux-gnu-libc2.19-0"

export PATH=$HEADAS/bin:$PATH
if test -z $LD_LIBRARY_PATH ; then export LD_LIBRARY_PATH=$HEADAS/lib ; else export LD_LIBRARY_PATH=$HEADAS/lib:$LD_LIBRARY_PATH ; fi
#-----------------------------------------------------------------
# Other packages: edit file default.libs (directory sass/setup) to 
# use your local versions instead of the ones supplied in the
# external directory.
#
# Comment out if you are not using the fft package in the external
# directory:
if test -z $LD_LIBRARY_PATH ; then export LD_LIBRARY_PATH=$SASS_DIR/external/fftw33 ; else export LD_LIBRARY_PATH=$SASS_DIR/external/fftw33:$LD_LIBRARY_PATH ; fi 
#=================================================================

if test $# -ne 1; then 
echo "Error: You must supply the release code, options are:"
/bin/ls $SASS_HOME/sw/*/RELEASE | awk '//{n=split($1,a,"/");print a[n-1]}'
else

source $SASS_HOME/caldb/software/tools/caldbinit.sh
export SASS_CALVERS=$SASS_HOME/caldb/data/erosita/calvers.indx

export SASS_ROOT=$SASS_DIR/$1
echo "SASS_ROOT: $SASS_ROOT"

export SASS_BIN_ROOT=$SASS_ROOT/bin
export PATH=$SASS_ROOT/bin:$PATH
export SASS_SETUP=$SASS_ROOT/sass/setup
export SW_ARCHIVE=$SASS_DIR/sw_archive
export SW_EXPARCH=$SASS_DIR/sw_exparch

source $SASS_SETUP/enable_sass.sh
source $SASS_SETUP/enable_erosita.sh

# Increase stack size:
ulimit -s 32768

echo "setup complete"

fi
